**bsmedit** is a C/C++/SystemC Visualizer.

Full doc: http://bsmedit.feiyilin.com

<img src="/web/images/start_run_plot.gif"></img>

SystemC is licensed under SystemC Open Source License.
See [here](/systemc-2.3.1/docs/SystemC_Open_Source_License.pdf) for more details.
